@@ -5,7 +5,7 @@
  *
  * memcached website: http://www.danga.com/memcached/
  *
- * Copyright 2007-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -383,9 +383,10 @@ class Horde_Memcache implements Serializable
      */
     public function lock($key)
     {
+        $i = 0;
+
         while ($this->_memcache->add($this->_key($key . self::LOCK_SUFFIX), 1, 0, self::LOCK_TIMEOUT) === false) {
-            /* Wait 0.1 secs before attempting again. */
-            usleep(100000);
+            usleep(min(pow(2, $i++) * 10000, 100000));
         }
 
         $this->_locks[$key] = true;
